@@ -1,5 +1,5 @@
 import os
-
+import nextcode
 
 def read_version():
     directory = os.path.dirname(__file__)
@@ -13,6 +13,6 @@ __version__, version_date = read_version()
 
 
 def get_version_string():
-    format_str = "nextcode-cli/{version} ({version_date})"
-    version_msg = format_str.format(version=__version__, version_date=version_date)
+    format_str = "nextcode-cli/{version} ({version_date}) nextcode-sdk/{sdk_version}"
+    version_msg = format_str.format(version=__version__, version_date=version_date, sdk_version=nextcode.__version__)
     return version_msg
