@@ -1,16 +1,11 @@
-import sys
 import datetime
 import click
 from click import command, argument, pass_context, secho, echo
-import requests
 import logging
 from tabulate import tabulate
-from requests import codes
-from urllib.parse import urljoin
 
 import nextcode
-from nextcode.utils import check_resp_error
-from nextcode.usermanage import KeycloakSession
+from nextcode.usermanage import KeycloakSession, CSASession
 from nextcode.exceptions import AuthServerError
 from nextcodecli.utils import abort, dumps, print_tab
 
@@ -18,6 +13,7 @@ log = logging.getLogger(__name__)
 
 CLIENT_ID = 'api-key-client'
 
+
 def _get_user(ctx, user_name):
     try:
         user = ctx.obj.session.get_user(user_name)
@@ -50,11 +46,16 @@ def cli(ctx, username, password, realm):
     """
     Manage keycloak users
 
-    Requires the keycloak admin password, which you can put into envivonment as KEYCLOAK_PASSWORD
+    Requires the keycloak admin password, which you can put into envivonment as KEYCLOAK_PASSWORD.
+
+    For CSA management the following environment vars are respected: CSA_USERNAME, CSA_PASSWORD
     """
     client = nextcode.Client()
     root_url = client.profile.root_url
-    session = KeycloakSession(root_url, username, password, realm)
+    try:
+        session = KeycloakSession(root_url, username, password, realm)
+    except AuthServerError as ex:
+        abort(ex)
     log.info("Managing users on keycloak server %s..." % session.auth_server)
     ctx.obj.session = session
 
@@ -134,7 +135,7 @@ def add_user(ctx, user_name, new_password):
 @click.option('-p', '--new_password', help='Password for new user', prompt=True)
 @pass_context
 def reset_password(ctx, user_name, new_password):
-    user = _get_user(ctx, user_name)
+    _ = _get_user(ctx, user_name)
     ctx.obj.session.set_user_password(user_name, new_password)
     echo("Password has been reset. Please use the following authentication information:\n")
     echo(
@@ -148,7 +149,7 @@ def reset_password(ctx, user_name, new_password):
 @argument('user_name', nargs=1)
 @pass_context
 def remove_user(ctx, user_name):
-    user = _get_user(ctx, user_name)
+    _ = _get_user(ctx, user_name)
     session = ctx.obj.session
     session.delete_user(user_name)
     secho("User '%s' has been deleted" % (user_name), bold=True)
@@ -159,7 +160,7 @@ def remove_user(ctx, user_name):
 @argument('role_name', nargs=1)
 @pass_context
 def add_role(ctx, user_name, role_name):
-    user = _get_user(ctx, user_name)
+    _ = _get_user(ctx, user_name)
     session = ctx.obj.session
     role_name = role_name.lower()
     user_roles = session.get_user_roles(user_name)
@@ -184,10 +185,9 @@ def add_role(ctx, user_name, role_name):
 @argument('role_name', nargs=1)
 @pass_context
 def remove_role(ctx, user_name, role_name):
-    user = _get_user(ctx, user_name)
+    _ = _get_user(ctx, user_name)
     session = ctx.obj.session
     role_name = role_name.lower()
-    user = session.get_user(user_name)
     try:
         session.remove_role_from_user(user_name, role_name)
     except AuthServerError as ex:
@@ -199,6 +199,8 @@ def remove_role(ctx, user_name, role_name):
         fg='green',
     )
 
+
+
 @command(help="Create a new role on the server")
 @argument('role_name', nargs=1)
 @pass_context
@@ -216,6 +218,7 @@ def create_server_role(ctx, role_name):
         fg='green',
     )
 
+
 @command(help="Create a new role on the server")
 @argument('role_name', nargs=1)
 @pass_context
@@ -234,6 +237,43 @@ def delete_server_role(ctx, role_name):
     )
 
 
+@command(help="Add a new CSA user in a project")
+@argument('user_name', nargs=1)
+@argument('password', nargs=1)
+@argument('project', nargs=1)
+@click.option(
+    '-u',
+    '--admin-username',
+    envvar='CSA_USERNAME',
+    prompt=True,
+    help="Username for CSA administrator user",
+    hide_input=True,
+)
+@click.option(
+    '-p',
+    '--admin-password',
+    envvar='CSA_PASSWORD',
+    prompt=True,
+    help="Password for CSA administrator user",
+    hide_input=True,
+)
+@pass_context
+def add_csa_user(ctx, user_name, password, project, admin_username, admin_password):
+    client = nextcode.Client()
+    root_url = client.profile.root_url
+    try:
+        session = CSASession(root_url, admin_username, admin_password)
+    except AuthServerError as ex:
+        abort(ex)
+
+    try:
+        session.create_user(user_name, password)
+    except AuthServerError as ex:
+        click.echo(str(ex))
+
+    session.add_user_to_project(user_name, project, exist_ok=True)
+    click.secho("User {} is now available in CSA project {}".format(user_name, project), bold=True)
+
 
 cli.add_command(users)
 cli.add_command(user)
@@ -244,3 +284,4 @@ cli.add_command(add_role)
 cli.add_command(remove_role)
 cli.add_command(create_server_role)
 cli.add_command(delete_server_role)
+cli.add_command(add_csa_user)
