@@ -10,6 +10,7 @@ import logging
 
 from nextcode.config import get_profile_config, get_default_profile, create_profile
 from nextcode.exceptions import InvalidProfile
+from nextcode.usermanage import login_keycloak_user
 from nextcodecli.utils import abort, dumps
 
 log = logging.getLogger(__name__)
@@ -30,7 +31,7 @@ log = logging.getLogger(__name__)
     '--token',
     'is_token',
     is_flag=True,
-    help="Return access tokens as json instead of writing into current profile",
+    help="Return refresh token instead of writing into current profile",
 )
 @pass_context
 def cli(ctx, username, password, realm, host, is_token):
@@ -43,33 +44,14 @@ def cli(ctx, username, password, realm, host, is_token):
     if username and password:
         if not is_token:
             echo("Authenticating from commandline parameters")
-        client_id = 'api-key-client'
-        body = {
-            'grant_type': 'password',
-            'client_id': client_id,
-            'password': password,
-            'username': username,
-            'scope': 'offline_access',
-        }
-        if host:
-            auth_server = "https://%s/auth" % host
-        else:
-            auth_server = config["root_url"] + "/auth"
-        log.info("Using auth server '%s'" % auth_server)
-        url = '%s/realms/%s/protocol/openid-connect/token' % (auth_server, realm)
-        headers = {"Content-Type": "application/x-www-form-urlencoded"}
-        log.debug("Calling POST %s with headers %s and body %s", url, headers, body)
-        resp = requests.post(url, headers=headers, data=body)
-        log.debug("Response (%s): %s", resp.status_code, resp.text)
-        if resp.status_code != 200:
-            click.secho("Error logging in: %s" % resp.text, fg='red')
-            sys.exit(1)
+        host = host or config["root_url"]
+        api_key = login_keycloak_user(host, username, password, realm=realm)
         if is_token:
-            echo(dumps(resp.json()))
+            click.echo(api_key)
             return
-        with open(config.token_files['refresh_token'], 'w') as f:
-            f.write(resp.json()['refresh_token'])
-        echo("You have been logged in")
+        create_profile(profile_name, api_key=api_key, root_url=host)
+        click.secho("Profile {} has been updated with api key".format(profile_name), bold=True)
+
     else:
         if host:
             root_url = "https://%s" % host
