@@ -33,6 +33,7 @@ log = logging.getLogger(__name__)
 @option(
     '-q', '--nowait', is_flag=True, help='Do not execute the watch command for a running pipeline'
 )
+@option('-d', '--description', help='A human readable description of the job')
 @pass_context
 def run(
     ctx,
@@ -46,6 +47,7 @@ def run(
     job_filename,
     nowait,
     trace,
+    description,
 ):
     """
     Start a new nextflow job.
@@ -122,6 +124,7 @@ def run(
             build_context,
             profile,
             trace,
+            description=description,
         )
     except ServerError as e:
         abort(str(e))
