@@ -144,4 +144,4 @@ def abort(reason, code=1):
 
 def check_profile(ctx):
     if not ctx.obj.client:
-        abort("You have no active profile or selected profile is invalid.")
+        abort("You have no active profile or selected profile is invalid. Run 'nextcode profile add [name]'")
